/*
 * Copyright (c) 2008--2012 by Jeffrey Ratcliffe <Jeffrey.Ratcliffe@gmail.com>
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the same terms as Perl itself, either Perl version 5.8.5 or,
 * at your option, any later version of Perl 5 you may have available.
 */

#ifndef _TIFFPERL_H_
#define _TIFFPERL_H_

/* Include all of libtiff's headers for internal consistency */
#include <tiffio.h>

#endif /* _TIFFPERL_H_ */
